@@ -1,22 +1,22 @@
-folderClosed = new Image(22,22);
+var folderClosed = new Image(22,22);
 folderClosed.src='/style/Crystal/22/html-menu-treeview/folderClosed.gif';
-plusNode = new Image(22,22);
+var plusNode = new Image(22,22);
 plusNode.src='/style/Crystal/22/html-menu-treeview/plusNode.gif';
-lastPlusNode = new Image(22,22);
+var lastPlusNode = new Image(22,22);
 lastPlusNode.src='/style/Crystal/22/html-menu-treeview/lastPlusNode.gif';
-clasicPlusNode = new Image(22,22);
+var clasicPlusNode = new Image(22,22);
 clasicPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicPlusNode.gif';
-clasicLastPlusNode = new Image(22,22);
+var clasicLastPlusNode = new Image(22,22);
 clasicLastPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicLastPlusNode.gif';
-folderGray = new Image(22,22);
+var folderGray = new Image(22,22);
 folderGray.src='/style/Crystal/22/html-menu-treeview/folderGray.gif';
-folderGreen = new Image(22,22);
+var folderGreen = new Image(22,22);
 folderGreen.src='/style/Crystal/22/html-menu-treeview/folderGreen.gif';
-folderViolet = new Image(22,22);
+var folderViolet = new Image(22,22);
 folderViolet.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
-folderYellowClosed = new Image(22,22);
+var folderYellowClosed = new Image(22,22);
 folderYellowClosed.src='/style/Crystal/22/html-menu-treeview/folderYellowClosed.gif';
-folderOrangeClosed = new Image(22,22);
+var folderOrangeClosed = new Image(22,22);
 folderOrangeClosed.src='/style/Crystal/22/html-menu-treeview/folderOrangeClosed.gif';
-folderPrintClosed = new Image(22,22);
+var folderPrintClosed = new Image(22,22);
 folderPrintClosed.src='/style/Crystal/22/html-menu-treeview/folderPrintClosed.gif';
